==> haskell-free-4.12.4-3-armv7h.pkg.tar.xz: usr/share/haskell/haskell-free/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 4.12.4
id: free-4.12.4-8d0ac6ee234521bdeedfa7d6a48e90f0
key: free_HhIWsreQpSoGfivHdR5Yb9
license: BSD3
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Applicative.Free Control.Applicative.Free.Final
    Control.Applicative.Trans.Free Control.Alternative.Free
    Control.Alternative.Free.Final Control.Comonad.Cofree
    Control.Comonad.Cofree.Class Control.Comonad.Trans.Cofree
    Control.Comonad.Trans.Coiter Control.Monad.Free
    Control.Monad.Free.Church Control.Monad.Free.Class
    Control.Monad.Free.TH Control.Monad.Trans.Free
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/free-4.12.4
hs-libraries: HSfree-4.12.4-HhIWsreQpSoGfivHdR5Yb9
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2-619b831167660978b6565dca15515574
    comonad-5-e53ff69c5983127cf4f20e90dd6b5c9a
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    distributive-0.5.0.2-921805b919081e64e9b7d8c792bc35e0
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    prelude-extras-0.4.0.3-1ebda3e30d44e52e3bbcd33027a32ddc
    profunctors-5.2-9a29145c6a42bab58852d072f6668ae3
    semigroupoids-5.0.1-c9d0eca57950bc8d0c89b9563eaf12c5
    semigroups-0.18.0.1-8982ad8edd41304214263f489c2b00c2
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-4.12.4-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-free/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 4.12.4
id: free-4.12.4-6ceee3b0778288ec7c5c8e8d64937985
key: free_JtYkRgqd7lPA2FmykZrbfK
license: BSD3
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
author: Edward A. Kmett
exposed: True
exposed-modules:
    Control.Applicative.Free Control.Applicative.Free.Final
    Control.Applicative.Trans.Free Control.Alternative.Free
    Control.Alternative.Free.Final Control.Comonad.Cofree
    Control.Comonad.Cofree.Class Control.Comonad.Trans.Cofree
    Control.Comonad.Trans.Coiter Control.Monad.Free
    Control.Monad.Free.Church Control.Monad.Free.Class
    Control.Monad.Free.TH Control.Monad.Trans.Free
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
library-dirs: /usr/lib/ghc-7.10.3/site-local/free-4.12.4
data-dir: /usr/share/arm-linux-ghc-7.10.3/free-4.12.4
hs-libraries: HSfree-4.12.4-JtYkRgqd7lPA2FmykZrbfK
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bifunctors-5.2.1-f15ad2d16f9be29f17cf3cf758fe7ba6
    comonad-5-530ea4e1d08a0115920b946124e760ac
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    distributive-0.5.0.2-17a8848c95a42a5c612669379433d996
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
    prelude-extras-0.4.0.3-1ebda3e30d44e52e3bbcd33027a32ddc
    profunctors-5.2-1b9f80ec12ba976fbd92d616f7b33d0d
    semigroupoids-5.0.1-fafa53fc1a76ec617ee4419105d11368
    semigroups-0.18.1-4a4dee25d838ab8c8d38a0caa045cf78
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-compat-0.5.1.4-b5340b5b89d4b4066d5de0d53e173907
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
